==========
eazyserver
==========


.. image:: https://img.shields.io/pypi/v/eazyserver.svg
        :target: https://pypi.python.org/pypi/eazyserver

.. image:: https://img.shields.io/travis/ashutoshdtu/eazyserver.svg
        :target: https://travis-ci.org/ashutoshdtu/eazyserver

.. image:: https://readthedocs.org/projects/eazyserver/badge/?version=latest
        :target: https://eazyserver.readthedocs.io/en/latest/?badge=latest
        :alt: Documentation Status

.. image:: https://pyup.io/repos/github/ashutoshdtu/eazyserver/shield.svg
     :target: https://pyup.io/repos/github/ashutoshdtu/eazyserver/
     :alt: Updates

.. image:: https://pyup.io/repos/github/ashutoshdtu/eazyserver/python-3-shield.svg
     :target: https://pyup.io/repos/github/ashutoshdtu/eazyserver/
     :alt: Python 3

A simple python web framework for creating RESTful and JSON-RPC services


* Free and open source software: `MIT license`_
* Documentation: https://eazyserver.readthedocs.io.
* GitHub: https://github.com/ashutoshdtu/eazyserver.
* PyPi: https://pypi.python.org/pypi/eazyserver

Features
--------

Did someone say features?

* Cross-platform: Windows, Mac, and Linux are officially supported.

* Works with Python 2.7, 3.4, 3.5, 3.6, and PyPy.

* Supports RESTful APIs over mongodb datasource using Python Eve.

* Supports JSON-RPC APIs using jsonrpcserver. 

* Kubernetes ready cookiecutter to easily scaffold an eazy API service with Dockerfile, Helm chart, and a Drone CI build pipeline (more on the way). 

* APIs are exposed over HTTP, HTTPs, Socket.IO and Kafka interface. 

* Auto generated documentation is available on a <DOCUMENTATION ROUTE> in the application. 


Credits
-------

This package was created with Cookiecutter_ and the `audreyr/cookiecutter-pypackage`_ project template.

.. _Cookiecutter: https://github.com/audreyr/cookiecutter
.. _`audreyr/cookiecutter-pypackage`: https://github.com/audreyr/cookiecutter-pypackage
.. _`MIT license`: https://github.com/ashutoshdtu/eazyserver/blob/master/LICENSE